# External Libraries

There is a family of external libraries that fall under the Torii banner, they provide things such as additional simulation backend support, to things like USB or Integrated Logic Analyzers that can be used in Torii based designs.

## Protocol & Peripherals

The following packages add protocol and peripheral support to Torii.

* [torii-usb]: A USB2 and USB3 library for Torii allowing you to make USB devices.

## Debugging

The following packages provide additional debugging capabilities.

* [torii-ila]: A simple Integrated Logic Analyzer (ILA) that lets you view signals in your design on a host machine over UART or USB.

[torii-usb]: https://github.com/shrine-maiden-heavy-industries/torii-usb
[torii-ila]: https://github.com/shrine-maiden-heavy-industries/torii-ila
